==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <source>compress...</source>
        <translation type="vanished">压缩...</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="66"/>
        <source>compress</source>
        <translation>komprimieren</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="82"/>
        <source>uncompress to current path</source>
        <translation>Dekomprimieren Sie auf den aktuellen Pfad</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="93"/>
        <source>uncompress to specific path...</source>
        <translation>Dekomprimieren Sie auf einen bestimmten Pfad...</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>Pfingstrose-Qt engrampa Erweiterung</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>engrampa Menu Extension</source>
        <translation>engrampa Menüerweiterung</translation>
    </message>
    <message>
        <source>engrampa Menu Extension.</source>
        <translation type="vanished">归档菜单扩展。</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-engrampa-menu-plugin/translations/peony-engrampa-menu_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Peony::EngrampaMenuPlugin</name>
    <message>
        <source>compress...</source>
        <translation type="vanished">压缩...</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="74"/>
        <source>compress</source>
        <translation>komprimieren</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="90"/>
        <source>uncompress to current path</source>
        <translation>Dekomprimieren Sie auf den aktuellen Pfad</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.cpp" line="101"/>
        <source>uncompress to specific path...</source>
        <translation>Dekomprimieren Sie auf einen bestimmten Pfad...</translation>
    </message>
    <message>
        <source>uncompress to specific path</source>
        <translation type="vanished">解压缩到...</translation>
    </message>
    <message>
        <source>Peony-Qt KArchive Menu Extension</source>
        <translation type="vanished">文件压缩插件</translation>
    </message>
    <message>
        <source>KArchive Menu Extension.</source>
        <translation type="vanished">压缩菜单扩展。</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="40"/>
        <source>Peony-Qt engrampa Extension</source>
        <translation>Pfingstrose-Qt engrampa Erweiterung</translation>
    </message>
    <message>
        <location filename="../engrampa-menu-plugin.h" line="41"/>
        <source>Engrampa Menu Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>engrampa Menu Extension</source>
        <translation type="vanished">engrampa Menüerweiterung</translation>
    </message>
    <message>
        <source>engrampa Menu Extension.</source>
        <translation type="vanished">归档菜单扩展。</translation>
    </message>
</context>
</TS>
